@@ -139,6 +139,13 @@ class LdapConnection implements Selectable, Inspectable
      */
     protected $root;
 
+    /**
+     * LDAP_OPT_NETWORK_TIMEOUT for the LDAP connection
+     *
+     * @var int
+     */
+    protected $timeout;
+
     /**
      * The properties and capabilities of the LDAP server
      *
@@ -178,7 +185,8 @@ class LdapConnection implements Selectable, Inspectable
         $this->bindDn = $config->bind_dn;
         $this->bindPw = $config->bind_pw;
         $this->rootDn = $config->root_dn;
-        $this->port = $config->get('port', 389);
+        $this->port = (int) $config->get('port', 389);
+        $this->timeout = (int) $config->get('timeout', 5);
 
         $this->encryption = $config->encryption;
         if ($this->encryption !== null) {
@@ -336,11 +344,10 @@ class LdapConnection implements Selectable, Inspectable
         $success = @ldap_bind($ds, $this->bindDn, $this->bindPw);
         if (! $success) {
             throw new LdapException(
-                'LDAP bind (%s / %s) to %s with default port %s failed: %s',
+                'LDAP bind (%s / %s) to %s failed: %s',
                 $this->bindDn,
                 '***' /* $this->bindPw */,
-                $this->hostname,
-                $this->port,
+                $this->normalizeHostname($this->hostname),
                 ldap_error($ds)
             );
         }
@@ -1171,25 +1178,13 @@ class LdapConnection implements Selectable, Inspectable
             $info = new Inspection('');
         }
 
-        $hostname = $this->hostname;
-        if ($this->encryption === static::LDAPS) {
-            $info->write('Connect using LDAPS');
-            $ldapUrls = explode(' ', $hostname);
-            if (count($ldapUrls) > 1) {
-                foreach ($ldapUrls as & $uri) {
-                    if (strpos($uri, '://') === false) {
-                        $uri = 'ldaps://' . $uri;
-                    }
-                }
-
-                $hostname = implode(' ', $ldapUrls);
-            } else {
-                $hostname = 'ldaps://' . $hostname;
-            }
-        }
+        $hostname = $this->normalizeHostname($this->hostname);
 
         $ds = ldap_connect($hostname, $this->port);
 
+        // Set a proper timeout for each connection
+        ldap_set_option($ds, LDAP_OPT_NETWORK_TIMEOUT, $this->timeout);
+
         // Usage of ldap_rename, setting LDAP_OPT_REFERRALS to 0 or using STARTTLS requires LDAPv3.
         // If this does not work we're probably not in a PHP 5.3+ environment as it is VERY
         // unlikely that the server complains about it by itself prior to a bind request
@@ -1198,7 +1193,9 @@ class LdapConnection implements Selectable, Inspectable
         // Not setting this results in "Operations error" on AD when using the whole domain as search base
         ldap_set_option($ds, LDAP_OPT_REFERRALS, 0);
 
-        if ($this->encryption === static::STARTTLS) {
+        if ($this->encryption === static::LDAPS) {
+            $info->write('Connect using LDAPS');
+        } elseif ($this->encryption === static::STARTTLS) {
             $this->encrypted = true;
             $info->write('Connect using STARTTLS');
             if (! ldap_start_tls($ds)) {
@@ -1242,23 +1239,6 @@ class LdapConnection implements Selectable, Inspectable
             // We're checking the level by ourselves to avoid rendering the ldapsearch commandline for nothing
             $starttlsParam = $this->encryption === static::STARTTLS ? ' -ZZ' : '';
 
-            $ldapUrls = array();
-            $defaultScheme = $this->encryption === static::LDAPS ? 'ldaps://' : 'ldap://';
-            foreach (explode(' ', $this->hostname) as $uri) {
-                $url = Url::fromPath($uri);
-                if (! $url->getScheme()) {
-                    $uri = $defaultScheme . $uri . ($this->port ? ':' . $this->port : '');
-                } else {
-                    if ($url->getPort() === null) {
-                        $url->setPort($this->port);
-                    }
-
-                    $uri = $url->getAbsoluteUrl();
-                }
-
-                $ldapUrls[] = $uri;
-            }
-
             $bindParams = '';
             if ($this->bound) {
                 $bindParams = ' -D "' . $this->bindDn . '"' . ($this->bindPw ? ' -W' : '');
@@ -1277,7 +1257,7 @@ class LdapConnection implements Selectable, Inspectable
             Logger::debug("Issueing LDAP search. Use '%s' to reproduce.", sprintf(
                 'ldapsearch -P 3%s -H "%s"%s -b "%s" -s "%s" -z %u -l %u -a "%s"%s%s%s',
                 $starttlsParam,
-                implode(' ', $ldapUrls),
+                $this->normalizeHostname($this->hostname),
                 $bindParams,
                 $baseDn,
                 $scope,
@@ -1497,11 +1477,10 @@ class LdapConnection implements Selectable, Inspectable
         // Try a bind-command with the given user credentials, this must not fail
         $success = @ldap_bind($ds, $this->bindDn, $this->bindPw);
         $msg = sprintf(
-            'LDAP bind (%s / %s) to %s with default port %s',
+            'LDAP bind (%s / %s) to %s',
             $this->bindDn,
             '***' /* $this->bindPw */,
-            $this->hostname,
-            $this->port
+            $this->normalizeHostname($this->hostname)
         );
         if (! $success) {
             // ldap_error does not return any proper error messages in case of certificate errors. Connecting
@@ -1532,4 +1511,33 @@ class LdapConnection implements Selectable, Inspectable
         }
         return $insp;
     }
+
+    protected function normalizeHostname($hostname)
+    {
+        $scheme = $this->encryption === static::LDAPS ? 'ldaps://' : 'ldap://';
+        $normalizeHostname = function ($hostname) use ($scheme) {
+            if (strpos($hostname, $scheme) === false) {
+                $hostname = $scheme . $hostname;
+            }
+
+            if (! preg_match('/:\d+$/', $hostname)) {
+                $hostname .= ':' . $this->port;
+            }
+
+            return $hostname;
+        };
+
+        $ldapUrls = explode(' ', $hostname);
+        if (count($ldapUrls) > 1) {
+            foreach ($ldapUrls as & $uri) {
+                $uri = $normalizeHostname($uri);
+            }
+
+            $hostname = implode(' ', $ldapUrls);
+        } else {
+            $hostname = $normalizeHostname($hostname);
+        }
+
+        return $hostname;
+    }
 }
