@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 class Zend_View_Helper_Customvar extends Zend_View_Helper_Abstract
 {
@@ -16,11 +16,11 @@ class Zend_View_Helper_Customvar extends Zend_View_Helper_Abstract
     public function customvar($struct)
     {
         if (is_scalar($struct)) {
-            return $this->view->escape(
+            return nl2br($this->view->escape(
                 is_string($struct)
                     ? $struct
                     : var_export($struct, true)
-            );
+            ), false);
         } elseif (is_array($struct)) {
             return $this->renderArray($struct);
         } elseif (is_object($struct)) {
@@ -55,6 +55,4 @@ class Zend_View_Helper_Customvar extends Zend_View_Helper_Abstract
         }
         return $out . "</ul>}";
     }
-
 }
-
