@@ -107,7 +107,12 @@
 
             // Ask for a new window id in case we don't already have one
             if (this.icinga.ui.hasWindowId()) {
-                headers['X-Icinga-WindowId'] = this.icinga.ui.getWindowId();
+                var windowId = this.icinga.ui.getWindowId();
+                var containerId = this.icinga.ui.getUniqueContainerId($target);
+                if (containerId) {
+                    windowId = windowId + '_' + containerId;
+                }
+                headers['X-Icinga-WindowId'] = windowId;
             } else {
                 headers['X-Icinga-WindowId'] = 'undefined';
             }
@@ -139,10 +144,15 @@
             req.fail(this.onFailure);
             req.complete(this.onComplete);
             req.autorefresh = autorefresh;
+            req.method = method;
             req.action = action;
             req.addToHistory = true;
             req.progressTimer = progressTimer;
 
+            if (url.match(/#/)) {
+                req.forceFocus = url.split(/#/)[1];
+            }
+
             if (id) {
                 this.requests[id] = req;
             }
@@ -349,10 +359,7 @@
                 return true;
             }
 
-            this.redirectToUrl(
-                redirect, req.$target, req.url, req.getResponseHeader('X-Icinga-Rerender-Layout'), req.forceFocus,
-                req.getResponseHeader('X-Icinga-Refresh')
-            );
+            this.redirectToUrl(redirect, req.$target, req);
             return true;
         },
 
@@ -361,14 +368,20 @@
          *
          * @param {string}  url
          * @param {object}  $target
-         * @param {string}  origin
-         * @param {boolean} rerenderLayout
+         * @param {XMLHttpRequest} referrer
          */
-        redirectToUrl: function (url, $target, origin, rerenderLayout, forceFocus, autoRefreshInterval) {
-            var icinga = this.icinga;
+        redirectToUrl: function (url, $target, referrer) {
+            var icinga = this.icinga,
+                rerenderLayout,
+                autoRefreshInterval,
+                forceFocus,
+                origin;
 
-            if (typeof rerenderLayout === 'undefined') {
-                rerenderLayout = false;
+            if (typeof referrer !== 'undefined') {
+                rerenderLayout = referrer.getResponseHeader('X-Icinga-Rerender-Layout');
+                autoRefreshInterval = referrer.autoRefreshInterval;
+                forceFocus = referrer.forceFocus;
+                origin = referrer.url;
             }
 
             icinga.logger.debug(
@@ -416,6 +429,7 @@
                     var req = this.loadUrl(url, $target);
                     req.forceFocus = url === origin ? forceFocus : null;
                     req.autoRefreshInterval = autoRefreshInterval;
+                    req.referrer = referrer;
                 }
             }
         },
@@ -448,9 +462,8 @@
                 this.failureNotice = null;
             }
 
-            var url = req.url;
             this.icinga.logger.debug(
-                'Got response for ', req.$target, ', URL was ' + url
+                'Got response for ', req.$target, ', URL was ' + req.url
             );
             this.processNotificationHeader(req);
 
@@ -531,7 +544,7 @@
 
             var title = req.getResponseHeader('X-Icinga-Title');
             if (title && ! req.autorefresh && req.$target.closest('.dashboard').length === 0) {
-                this.icinga.ui.setTitle(decodeURIComponent(title));
+                req.$target.data('icingaTitle', decodeURIComponent(title));
             }
 
             // Set a window identifier if the server asks us to do so
@@ -570,6 +583,20 @@
                 rendered = true;
             }
 
+            var referrer = req.referrer;
+            if (typeof referrer === 'undefined') {
+                referrer = req;
+            }
+
+            var autoSubmit = false;
+            if (referrer.method === 'POST') {
+                var newUrl = this.icinga.utils.parseUrl(req.url);
+                var currentUrl = this.icinga.utils.parseUrl(req.$target.data('icingaUrl'));
+                if (newUrl.path === currentUrl.path && this.icinga.utils.objectsEqual(newUrl.params, currentUrl.params)) {
+                    autoSubmit = true;
+                }
+            }
+
             req.$target.data('icingaUrl', req.url);
 
             this.icinga.ui.initializeTriStates($resp);
@@ -583,13 +610,10 @@
             }
 
             // .html() removes outer div we added above
-            this.renderContentToContainer($resp.html(), req.$target, req.action, req.autorefresh, req.forceFocus);
+            this.renderContentToContainer($resp.html(), req.$target, req.action, req.autorefresh, req.forceFocus, autoSubmit);
             if (oldNotifications) {
                 oldNotifications.appendTo($('#notifications'));
             }
-            if (url.match(/#/)) {
-                setTimeout(this.icinga.ui.focusElement, 0, url.split(/#/)[1], req.$target);
-            }
             if (newBody) {
                 this.icinga.ui.fixDebugVisibility().triggerWindowResize();
             }
@@ -610,7 +634,7 @@
                 var url = req.url;
 
                 if (req.$target[0].id === 'col1') {
-                    this.icinga.behaviors.navigation.trySetActiveByUrl(url);
+                    this.icinga.behaviors.navigation.trySetActiveAndSelectedByUrl(url);
                 }
 
                 var $forms = $('[action="' + this.icinga.utils.parseUrl(url).path + '"]');
@@ -756,17 +780,22 @@
         /**
          * Smoothly render given HTML to given container
          */
-        renderContentToContainer: function (content, $container, action, autorefresh, forceFocus) {
+        renderContentToContainer: function (content, $container, action, autorefresh, forceFocus, autoSubmit) {
             // Container update happens here
             var scrollPos = false;
             var _this = this;
             var containerId = $container.attr('id');
 
             var activeElementPath = false;
+            var navigationAnchor = false;
             var focusFallback = false;
 
             if (forceFocus && forceFocus.length) {
-                activeElementPath = this.icinga.utils.getCSSPath($(forceFocus));
+                if (typeof forceFocus === 'string') {
+                    navigationAnchor = forceFocus;
+                } else {
+                    activeElementPath = this.icinga.utils.getCSSPath($(forceFocus));
+                }
             } else if (document.activeElement && document.activeElement.id === 'search') {
                 activeElementPath = '#search';
             } else if (document.activeElement
@@ -785,8 +814,8 @@
                 activeElementPath = this.icinga.utils.getCSSPath($activeElement);
             }
 
-            if (typeof containerId !== 'undefined') {
-                if (autorefresh) {
+            if (! forceFocus && typeof containerId !== 'undefined') {
+                if (autorefresh || autoSubmit) {
                     scrollPos = $container.scrollTop();
                 } else {
                     scrollPos = 0;
@@ -844,7 +873,9 @@
             }
             this.icinga.ui.assignUniqueContainerIds();
 
-            if (! activeElementPath) {
+            if (navigationAnchor) {
+                setTimeout(this.icinga.ui.focusElement, 0, navigationAnchor, $container);
+            } else if (! activeElementPath) {
                 // Active element was not in this container
                 if (! autorefresh) {
                     setTimeout(function() {
@@ -862,7 +893,7 @@
                     var $activeElement = $(activeElementPath);
 
                     if ($activeElement.length && $activeElement.is(':visible')) {
-                        $activeElement.focus();
+                        $activeElement[0].focus({preventScroll: autorefresh});
                     } else if (! autorefresh) {
                         if (focusFallback) {
                             $(focusFallback.parent).find(focusFallback.child).focus();
@@ -874,14 +905,22 @@
                 }, 0);
             }
 
-            if (scrollPos !== false) {
-                setTimeout($container.scrollTop.bind($container), 0, scrollPos);
-            }
             var icinga = this.icinga;
             //icinga.events.applyHandlers($container);
             icinga.ui.initializeControls($container);
             icinga.ui.fixControls();
 
+            if (scrollPos !== false) {
+                $container.scrollTop(scrollPos);
+
+                // Fallback for browsers without support for focus({preventScroll: true})
+                setTimeout(function () {
+                    if ($container.scrollTop() !== scrollPos) {
+                        $container.scrollTop(scrollPos);
+                    }
+                }, 0);
+            }
+
             // Re-enable all click events (disabled as of performance reasons)
             // $('*').off('click');
         },
