@@ -27,6 +27,21 @@
          * @type {bool}
          */
         this.mobileMenu = false;
+
+        // detect currentLayout
+        var classList = $('#layout').attr('class').split(/\s+/);
+        var _this = this;
+        var matched;
+        $.each(classList, function(index, item) {
+            if (null !== (matched = item.match(/^([a-z]+)-layout$/))) {
+                var layout = matched[1];
+                if (layout !== 'fullscreen') {
+                    _this.currentLayout = layout;
+                    // Break loop
+                    return false;
+                }
+            }
+        });
     };
 
     Icinga.UI.prototype = {
@@ -171,7 +186,7 @@
             var kill = this.cutContainer($('#col1'));
             this.pasteContainer($('#col1'), col2);
             this.fixControls();
-            this.icinga.behaviors.navigation.trySetActiveByUrl($('#col1').data('icingaUrl'));
+            this.icinga.behaviors.navigation.trySetActiveAndSelectedByUrl($('#col1').data('icingaUrl'));
         },
 
         cutContainer: function ($col) {
@@ -179,17 +194,21 @@
               'elements': $('#' + $col.attr('id') + ' > *').detach(),
               'data': {
                 'data-icinga-url': $col.data('icingaUrl'),
+                'data-icinga-title': $col.data('icingaTitle'),
                 'data-icinga-refresh': $col.data('icingaRefresh'),
                 'data-last-update': $col.data('lastUpdate'),
-                'data-icinga-module': $col.data('icingaModule')
+                'data-icinga-module': $col.data('icingaModule'),
+                'data-icinga-container-id': $col.data('icingaContainerId')
               },
               'class': $col.attr('class')
             };
             this.icinga.loader.stopPendingRequestsFor($col);
             $col.removeData('icingaUrl');
+            $col.removeData('icingaTitle');
             $col.removeData('icingaRefresh');
             $col.removeData('lastUpdate');
             $col.removeData('icingaModule');
+            $col.removeData('icingaContainerId');
             $col.removeAttr('class').attr('class', 'container');
             return props;
         },
@@ -198,9 +217,11 @@
             backup['elements'].appendTo($col);
             $col.attr('class', backup['class']); // TODO: ie memleak? remove first?
             $col.data('icingaUrl', backup['data']['data-icinga-url']);
+            $col.data('icingaTitle', backup['data']['data-icinga-title']);
             $col.data('icingaRefresh', backup['data']['data-icinga-refresh']);
             $col.data('lastUpdate', backup['data']['data-last-update']);
             $col.data('icingaModule', backup['data']['data-icinga-module']);
+            $col.data('icingaContainerId', backup['data']['data-icinga-container-id']);
         },
 
         triggerWindowResize: function () {
@@ -279,6 +300,7 @@
 
         closeContainer: function($c) {
             $c.removeData('icingaUrl');
+            $c.removeData('icingaTitle');
             $c.removeData('icingaRefresh');
             $c.removeData('lastUpdate');
             $c.removeData('icingaModule');
@@ -354,6 +376,9 @@
         },
 
         refreshDebug: function () {
+            if (! this.debug) {
+                return;
+            }
 
             var size = this.getDefaultFontSize().toString();
             var winWidth = $( window ).width();
@@ -533,8 +558,10 @@
          * @param {object} e Event
          */
         closeMobileMenu: function(e) {
-            if (e.which === 13) {
+            var $search = $('#search');
+            if (e.which === 13 && $search.is(':focus')) {
                 $('#sidebar').removeClass('expanded');
+                $search.blur();
             }
         },
 
@@ -547,18 +574,22 @@
 
             $container.find('.controls').each(function() {
                 var $controls = $(this);
-                if (! $controls.next('.fake-controls').length) {
+                if (! $controls.prev('.fake-controls').length) {
                     var $tabs = $controls.find('.tabs', $controls);
                     if ($tabs.length && $controls.children().length > 1 && ! $tabs.next('.tabs-spacer').length) {
                         $tabs.after($('<div class="tabs-spacer"></div>'));
                     }
                     var $fakeControls = $('<div class="fake-controls"></div>');
                     $fakeControls.height($controls.height()).css({
-                        display: 'block'
+                        // That's only temporary. It's reset in fixControls, which is called at the end of this
+                        // function. Its purpose is to prevent the content from jumping up upon auto-refreshes.
+                        // It works by making the fake-controls appear at the same vertical level as the controls
+                        // and the height of the content then doesn't change when taking the controls out of the flow.
+                        float: 'right'
                     });
-                    $controls.css({
+                    $controls.before($fakeControls).css({
                         position: 'fixed'
-                    }).after($fakeControls);
+                    });
                 }
             });
 
@@ -574,7 +605,7 @@
 
             if (typeof $container === 'undefined') {
                 var $header = $('#header');
-                var $headerLogo = $('#header-logo');
+                var $headerLogo = $('#header-logo-container');
                 var $main = $('#main');
                 var $search = $('#search');
                 var $sidebar = $('#sidebar');
@@ -590,8 +621,7 @@
                             display: 'none'
                         });
                         $main.css({
-                            top: $header.height() + $sidebar.outerHeight(),
-                            zIndex: 2
+                            top: $header.outerHeight() + $sidebar.outerHeight()
                         });
                         $sidebar
                             .on(
@@ -600,28 +630,23 @@
                             )
                             .prepend(
                                 $('<div id="mobile-menu-toggle"><button><i class="icon-menu"></i></button></div>')
-                            )
-                            .css({
-                                paddingBottom: $('#mobile-menu-toggle').height(),
-                                top: 0,
-                                zIndex: 3
-                            });
-                        $search.on('keypress', this.closeMobileMenu);
+                            );
+                        $(window).on('keypress', this.closeMobileMenu);
 
                         this.mobileMenu = true;
                     }
                 } else {
+                    $headerLogo.css({
+                        top: $header.css('height')
+                    });
                     $main.css({
-                        top: $header.css('height'),
-                        zIndex: ''
-                    });
-                    $sidebar.css({
-                        top: $header.css('height'),
-                        zIndex: ''
-                    });
-                    $header.css({
-                        height: $header.height() + 'px'
+                        top: $header.css('height')
                     });
+                    if (!! $headerLogo.length) {
+                        $sidebar.css({
+                            top: $headerLogo.offset().top + $headerLogo.outerHeight()
+                        });
+                    }
 
                     if (this.mobileMenu) {
                         $header.css({
@@ -655,12 +680,15 @@
 
             $container.find('.controls').each(function() {
                 var $controls = $(this);
-                var $fakeControls = $controls.next('.fake-controls');
+                var $fakeControls = $controls.prev('.fake-controls');
+                $fakeControls.css({
+                    float: '', // Set by initializeControls
+                    height: $controls.height()
+                });
                 $controls.css({
-                    top: $container.offset().top,
+                    top: $container.offsetParent().position().top,
                     width: $fakeControls.outerWidth()
                 });
-                $fakeControls.height($controls.height());
             });
 
             var $statusBar = $container.children('.monitoring-statusbar');
@@ -678,21 +706,44 @@
             this.fixControls();
         },
 
+        getUniqueContainerId: function ($cont) {
+            if (typeof $cont === 'undefined' || !$cont.length) {
+                return null;
+            }
+
+            var containerId = $cont.data('icingaContainerId');
+            if (typeof containerId === 'undefined') {
+                /**
+                 * Only generate an id if it's not for col1 or the menu (which are using the non-suffixed window id).
+                 * This is based on the assumption that the server only knows about the menu and first column
+                 * and therefore does not need to protect its ids. (As the menu is most likely part of the sidebar)
+                 */
+                if ($cont.attr('id') === 'menu' || $cont.attr('id') === 'col1') {
+                    return null;
+                }
+
+                containerId = this.icinga.utils.generateId(6); // Random because the content may move
+                $cont.data('icingaContainerId', containerId);
+            }
+
+            return containerId;
+        },
+
         getWindowId: function () {
             if (! this.hasWindowId()) {
                 return undefined;
             }
-            return window.name.match(/^Icinga_([a-zA-Z0-9]+)$/)[1];
+            return window.name.match(/^Icinga-([a-zA-Z0-9]+)$/)[1];
         },
 
         hasWindowId: function () {
-            var res = window.name.match(/^Icinga_([a-zA-Z0-9]+)$/);
+            var res = window.name.match(/^Icinga-([a-zA-Z0-9]+)$/);
             return typeof res === 'object' && null !== res;
         },
 
         setWindowId: function (id) {
             this.icinga.logger.debug('Setting new window id', id);
-            window.name = 'Icinga_' + id;
+            window.name = 'Icinga-' + id;
         },
 
         destroy: function () {
