@@ -286,8 +286,7 @@
             while (true) {
                 var id = $node.attr('id');
 
-                // Ignore forms and form controls because id generation is unreliable :(
-                if (typeof id !== 'undefined' && ! $node.is(':input') && ! $node.is('form')) {
+                if (typeof id !== 'undefined') {
                     path.push('#' + id);
                     break;
                 }
@@ -352,6 +351,14 @@
             return keys;
         },
 
+        objectsEqual: function equals(obj1, obj2) {
+            return Object.keys(obj1)
+                .concat(Object.keys(obj2))
+                .every(function (key) {
+                    return obj1[key] === obj2[key];
+                });
+        },
+
         /**
          * Cleanup
          */
@@ -404,6 +411,37 @@
                 str = padding + str;
             }
             return str;
+        },
+
+        /**
+         * Shuffle a string
+         *
+         * @param   {String}    str     The string to shuffle
+         *
+         * @returns {String}    The shuffled string
+         */
+        shuffleString: function(str) {
+            var a = str.split(""),
+                n = a.length;
+
+            for(var i = n - 1; i > 0; i--) {
+                var j = Math.floor(Math.random() * (i + 1));
+                var tmp = a[i];
+                a[i] = a[j];
+                a[j] = tmp;
+            }
+            return a.join("");
+        },
+
+        /**
+         * Generate an id
+         *
+         * @param   {Number}    len     The desired length of the id
+         *
+         * @returns {String}    The id
+         */
+        generateId: function(len) {
+            return this.shuffleString('abcefghijklmnopqrstuvwxyz').substr(0, len);
         }
     };
 
